@@ -23,7 +23,6 @@ API_ENDPOINT_1 = "https://eurouter.ablecloud.cn:9005/zc-account/v1/"
 API_ENDPOINT_2 = "https://eurouter.ablecloud.cn:9005/millService/v1/"
 API_ENDPOINT_STATS = "https://api.millheat.com/statistics/"
 DEFAULT_TIMEOUT = 10
-MIN_TIME_BETWEEN_UPDATES = dt.timedelta(seconds=5)
 MIN_TIME_BETWEEN_STATS_UPDATES = dt.timedelta(minutes=10)
 REQUEST_TIMEOUT = "300"
 
@@ -81,7 +80,7 @@ class Mill:
         }
         payload = {"account": self._username, "password": self._password}
         try:
-            with async_timeout.timeout(self._timeout):
+            async with async_timeout.timeout(self._timeout):
                 resp = await self.websession.post(
                     url, data=json.dumps(payload), headers=headers
                 )
@@ -127,7 +126,7 @@ class Mill:
             _LOGGER.error("No token")
             return None
 
-        _LOGGER.debug(command, payload)
+        _LOGGER.debug("Request %s %s", command, payload)
 
         nonce = "".join(
             random.choice(string.ascii_uppercase + string.digits) for _ in range(16)
@@ -154,7 +153,7 @@ class Mill:
             "X-Zc-Content-Length": str(len(payload)),
         }
         try:
-            with async_timeout.timeout(self._timeout):
+            async with async_timeout.timeout(self._timeout):
                 resp = await self.websession.post(
                     url, data=json.dumps(payload), headers=headers
                 )
@@ -169,7 +168,7 @@ class Mill:
 
         result = await resp.text()
 
-        _LOGGER.debug(result)
+        _LOGGER.debug("Result %s", result)
 
         if not result or result == '{"errorCode":0}':
             return None
@@ -197,7 +196,7 @@ class Mill:
 
     async def request_stats(self, command, payload, retry=3):
         """Request data."""
-        _LOGGER.debug(command, payload)
+        _LOGGER.debug("Request stats %s %s", command, payload)
         url = API_ENDPOINT_STATS + command
         json_data = json.dumps(payload)
         token = str(int(time.time() * 1000)) + "_" + str(self._user_id)
@@ -215,7 +214,7 @@ class Mill:
             "milltoken": milltoken.decode(),
         }
         try:
-            with async_timeout.timeout(self._timeout):
+            async with async_timeout.timeout(self._timeout):
                 resp = await self.websession.post(url, data=json_data, headers=headers)
         except asyncio.TimeoutError:
             if retry < 1:
@@ -230,7 +229,7 @@ class Mill:
 
         result = await resp.text()
 
-        _LOGGER.debug(result)
+        _LOGGER.debug("Result %s", result)
         data = json.loads(result)
         return data
 
@@ -419,7 +418,9 @@ class Mill:
         now = dt.datetime.now(dt.timezone.utc)
         if heater.last_updated and (
             now - heater.last_updated
-        ) < MIN_TIME_BETWEEN_STATS_UPDATES + dt.timedelta(random.randint(0, 60)):
+        ) < MIN_TIME_BETWEEN_STATS_UPDATES + dt.timedelta(
+            seconds=random.randint(0, 60)
+        ):
             return
 
         payload = {
@@ -567,29 +568,41 @@ class Heater(MillDevice):
     year_consumption: float | None = None
     last_updated: dt.datetime | None = None
 
+    # 863: Panel Gen 1 5316: New Panel Heater 5317: Oil Heater
+    # 5332: Convection Heater 5333: Socket 6933: Sense Air
+    # https://api.millheat.com/swagger-ui.html#/uds-controller/selectRoombyHome2020UsingPOST_7
+
     @property
     def is_gen1(self):
         """Check if heater is gen 1."""
-        return self.sub_domain in [
-            863,
-        ]
+        return self.sub_domain in (863,)
+
+    @property
+    def is_gen2(self):
+        """Check if heater is gen 1."""
+        return self.sub_domain in (
+            5316,
+            5317,
+            5332,
+            5333,
+        )
 
     @property
     def is_gen3(self):
         """Check if heater is gen 3."""
-        return self.sub_domain in [
-            6980,
-            6979,
-        ]
+        return self.generation == 3
 
     @property
     def generation(self):
         """Get the generation of the heater."""
+        _LOGGER.debug("SubDomain %s", self.sub_domain)
         if self.is_gen1:
             return 1
-        if self.is_gen3:
-            return 3
-        return 2
+        if self.is_gen2:
+            return 2
+        if self.sub_domain in (6933,):
+            return -1  # Mill Sense
+        return 3
 
 
 def set_heater_values(heater_data, heater):
